Package: gen3sis
Type: Package
Title: General Engine for Eco-Evolutionary Simulations
Version: 1.6.0
Date: 2025-09-01
Authors@R: c(
  person("ETH Zürich", role=c("cph")),
  person("Oskar", "Hagen", email = "oskar@hagen.bio", role = c("aut", "cre"), comment = "Landscape Ecology, WSL and ETH Zürich, Switzerland"),
  person("Benjamin", "Flück", email="benjamin.flueck@alumni.ethz.ch", role = c("aut"), comment = "Landscape Ecology, WSL and ETH Zürich, Switzerland"),
  person("Fabian", "Fopp", email="fabian.fopp@usys.ethz.ch", role = c("aut"), comment = "Landscape Ecology, WSL and ETH Zürich, Switzerland"),
  person(c("Juliano","S."), "Cabral", email = "juliano.sarmento_cabral@uni-wuerzburg.de", role = c("aut"), comment = "Ecosystem Modeling, Center for Computational and Theoretical Biology, University of Würzburg, Würzburg, Germany"),
  person("Florian", "Hartig", email = "florian.hartig@biologie.uni-regensburg.de", role = c("aut"), comment = "Theoretical Ecology, University of Regensburg, Regensburg, Germany"), 
  person("Mikael", "Pontarp", email = "mikael.pontarp@biol.lu.se", role = c("aut"), comment = "Department of Biology, Lund University, Lund, Sweden"),
  person("Charles", "Novaes de Santana ", email = "charles.novaes@usys.ethz.ch", role = c("ctb"), comment = "Landscape Ecology, WSL and ETH Zürich, Switzerland"),
  person(c("Thiago", "F."), "Rangel", email = "rangel.tf@gmail.com", role = c("aut"), comment = "Department of Ecology, Universidade Federal de Goiás, Goiás, Brazil"),
  person("Theo", "Gaboriau", email = "theo.gaboriau@unil.ch", role = c("ctb"), comment = "Depatment of Computational Biology, Lausanne University, Switzerland"),
  person("Loïc", "Pellissier", email = "loic.pellissier@usys.ethz.ch", role = c("aut","ths"), comment = "Landscape Ecology, WSL and ETH Zürich, Switzerland"))
Description: Contains an engine for spatially-explicit eco-evolutionary mechanistic models with a modular implementation and several support functions. It allows exploring the consequences of ecological and macroevolutionary processes across realistic or theoretical spatio-temporal landscapes on biodiversity patterns as a general term. Reference: Oskar Hagen, Benjamin Flueck, Fabian Fopp, Juliano S. Cabral, Florian Hartig, Mikael Pontarp, Thiago F. Rangel, Loic Pellissier (2021) "gen3sis: A general engine for eco-evolutionary simulations of the processes that shape Earth's biodiversity" <doi:10.1371/journal.pbio.3001340>.
License: GPL-3
Encoding: UTF-8
Depends: R (>= 3.5.0)
Imports: Rcpp (>= 0.12.16), Matrix, methods, utils, raster, gdistance,
        stringr, tools, grDevices
Suggests: knitr, markdown, testthat (>= 3.2.0), rmarkdown, formatR
LinkingTo: Rcpp, BH
URL: https://github.com/project-Gen3sis/R-package
BugReports: https://github.com/project-Gen3sis/R-package/issues
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2025-09-01 14:17:18 UTC; ohagen
Author: ETH Zürich [cph],
  Oskar Hagen [aut, cre] (Landscape Ecology, WSL and ETH Zürich,
    Switzerland),
  Benjamin Flück [aut] (Landscape Ecology, WSL and ETH Zürich,
    Switzerland),
  Fabian Fopp [aut] (Landscape Ecology, WSL and ETH Zürich, Switzerland),
  Juliano S. Cabral [aut] (Ecosystem Modeling, Center for Computational
    and Theoretical Biology, University of Würzburg, Würzburg, Germany),
  Florian Hartig [aut] (Theoretical Ecology, University of Regensburg,
    Regensburg, Germany),
  Mikael Pontarp [aut] (Department of Biology, Lund University, Lund,
    Sweden),
  Charles Novaes de Santana [ctb] (Landscape Ecology, WSL and ETH Zürich,
    Switzerland),
  Thiago F. Rangel [aut] (Department of Ecology, Universidade Federal de
    Goiás, Goiás, Brazil),
  Theo Gaboriau [ctb] (Depatment of Computational Biology, Lausanne
    University, Switzerland),
  Loïc Pellissier [aut, ths] (Landscape Ecology, WSL and ETH Zürich,
    Switzerland)
Maintainer: Oskar Hagen <oskar@hagen.bio>
Repository: CRAN
Date/Publication: 2025-09-01 14:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 03:44:50 UTC; unix
Archs: gen3sis.so.dSYM
