# Generated by roxygen2: do not edit by hand

export(apply_ecology)
export(apply_evolution)
export(color_richness)
export(color_richness_non_CVDCBP)
export(create_ancestor_species)
export(create_input_config)
export(create_input_landscape)
export(create_species)
export(evolution_mode_none)
export(get_dispersal_values)
export(get_divergence_factor)
export(get_divergence_matrix)
export(get_geo_richness)
export(plot_landscape)
export(plot_landscape_overview)
export(plot_ranges)
export(plot_raster_multiple)
export(plot_raster_single)
export(plot_richness)
export(plot_species_abundance)
export(plot_species_presence)
export(plot_summary)
export(prepare_directories)
export(run_simulation)
export(save_abundance)
export(save_divergence)
export(save_landscape)
export(save_occupancy)
export(save_phylogeny)
export(save_richness)
export(save_species)
export(save_traits)
export(verify_config)
export(write_config_skeleton)
import(Matrix)
import(raster)
importFrom(Rcpp,sourceCpp)
importFrom(gdistance,costDistance)
importFrom(gdistance,geoCorrection)
importFrom(gdistance,transition)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,rgb)
importFrom(graphics,axis)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(methods,as)
importFrom(methods,is)
importFrom(stringr,str_extract)
importFrom(stringr,str_remove)
importFrom(stringr,str_replace)
importFrom(stringr,str_split)
importFrom(tools,file_path_sans_ext)
importFrom(utils,packageVersion)
importFrom(utils,sessionInfo)
importFrom(utils,write.table)
useDynLib(gen3sis, .registration = TRUE)
