\dontrun{
  ## save the current traits pattern from within observer for each population of each species
  # this functions should be called inside the end_of_timestep_observer function at the config file:
  save_traits()
}